@@ -194,10 +194,11 @@ def avnn2(comments_en,by_review = False,other_edges = True,verbose_text = False,
 
 
 ## -- avn network -- ## 
-def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = True,save_add ="avnn.html",height='600px', width='100%',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
+def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = False,save_add ="network_avnn.html",height='600px', width='100%',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
     """ all_edges1: weighted edges 
         core_k: if node degree is less than k then edge droped
         cdn=['remote','local'] more in pyvis 
+        plot_graph = False for google colab 
     """
     # get Networkx 
     #import math
@@ -268,6 +269,9 @@ def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = True,save_a
     nt.show_buttons(filter_=['physics']) 
     if plot_graph:
         display(nt.show("network_avnn.html"))
+    else: # google colab 
+        nt.show("network_avnn.html")
+        display(HTML('network_avnn.html'))
         #display(HTML('network_avnn.html'))
     if save_add:      
         nt.save_graph(save_add)
@@ -277,10 +281,11 @@ def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = True,save_a
 
 
 ## -- avn network colored by community 
-def communet(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,save_add ="network_community.html",height='600px', width='100%',heading='Community Network', directed = True, notebook =True,cdn='remote'):
+def communet(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = False,save_add ="community_network.html",height='600px', width='100%',heading='Community Network', directed = True, notebook =True,cdn='remote'):
     #import matplotlib
     """ 
         cdn=['remote','local'] more in pyvis 
+        plot_graph = False for google colab 
     """
     #from itertools import cycle, islice
     colorList1  = list(islice(cycle(colorList_rgba1),len(partition)))
@@ -327,9 +332,11 @@ def communet(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,save_
       #ntc.add_edge(edge[0][:-2],edge[1][:-2], title = elabel,width = value)
     ntc.show_buttons(filter_=['physics']) 
     if plot_graph:
-         
         display(ntc.show('community_network.html'))
         #display(HTML('community_network.html'))
+    else: # google colab
+        ntc.show("community_network.html")
+        display(HTML('community_network.html'))      
     if save_add:
         ntc.save_graph(save_add)
         
@@ -337,10 +344,11 @@ def communet(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,save_
 
 ## --plot color by nouns in AVNN community --#
 
-def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,save_add = 'community_NNColors.html', height='600px', width='100%',heading='Community_NNColors',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
+def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = False,save_add = 'community_NNColors.html', height='600px', width='100%',heading='Community_NNColors',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
     #import matplotlib,itertools
     """ 
         cdn=['remote','local'] more in pyvis 
+        plot_graph = False for google colab 
     """
     partition_all_names = [] 
     for index in partition:
@@ -446,6 +454,9 @@ def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,s
     if plot_graph:
         display(ntc2.show('communityNNcolor.html'))
         #display(HTML('communityNNcolor.html'))
+    else:# google colab
+        ntc2.show("communityNNcolor.html")
+        display(HTML('communityNNcolor.html'))      
     if save_add:
         ntc2.save_graph(save_add)
 
@@ -463,6 +474,7 @@ def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,s
 def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_folder='gray_units/',height='600px', width='100%',heading='Gray Unit Community Network',bgcolor='white',font_color="black", directed = True, notebook =True,cdn='remote'):
     """ 
         cdn=['remote','local'] more in pyvis 
+        plot_graph = False for google colab 
     """    
     
     if comLen == False:
@@ -550,6 +562,9 @@ def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_f
         if community_index == com_len-1: 
             display(ntc3.show(str(community_index) + '_gray_unit.html'))
             #display(HTML(str(community_index) + '_gray_unit.html'))
+      else:
+             ntc3.show(str(community_index) + '_gray_unit.html')
+             display(HTML(str(community_index) + '_gray_unit.html'))       
       if save_folder:
         ntc3.save_graph(save_folder+ '/{}.html'.format(community_index +1))
 
@@ -595,11 +610,11 @@ def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_f
     return colorGrayDF
   
 
-def compare_net(allWedges, weight_K=1, specEdges1 = False,specEdges2 = False, specNodes1=False,specNodes2=False, color1= 'red', color2 = 'green', save_add = False,heading = 'Compared Network',core_K = 1 , plot_graph = True, height='600px',width='100%',bgcolor='white', font_color="black",directed = True,notebook =True,cdn='remote'):
+def compare_net(allWedges, weight_K=1, specEdges1 = False,specEdges2 = False, specNodes1=False,specNodes2=False, color1= 'red', color2 = 'green', save_add = False,heading = 'Compared Network',core_K = 1 , plot_graph = False, height='600px',width='100%',bgcolor='white', font_color="black",directed = True,notebook =True,cdn='remote'):
     """ 
     allWEdges  of list of weighted edges including SharedA, ShareB, SpecificA, SpecificB edges 
     if specedge or specnodes False, color1 , color2 do not work all show gray color
-    
+    plot_graph = False for google colab 
     """
     nt=Network(heading=heading, height=height, width=width,bgcolor=bgcolor,font_color=font_color, directed = directed, notebook =notebook,cdn_resources=cdn)
     nt.set_edge_smooth('cubicBezier')
@@ -707,6 +722,9 @@ def compare_net(allWedges, weight_K=1, specEdges1 = False,specEdges2 = False, sp
         nt.save_graph(save_add) 
     if plot_graph:
         display(nt.show("compare_avnn.html"))
+    else: # google colab
+        nt.show("compare_avnn.html")
+        display(HTML('compare_avnn.html'))
 
     return all_nodes, specNodes1_new,specNodes2_new ,all_edges,  specEdges1new,specEdges2new
 
